aboutsummaryrefslogtreecommitdiffstats
path: root/XMonad/Actions/Search.hs
diff options
context:
space:
mode:
authorgwern0 <gwern0@gmail.com>2008-10-31 22:49:37 +0100
committergwern0 <gwern0@gmail.com>2008-10-31 22:49:37 +0100
commit5256f6f0aa92b0c2c9a1cd5a45ef25014510eaa1 (patch)
tree2278458ddcab18ef1d682646a5570ee5cf7c9de6 /XMonad/Actions/Search.hs
parent98583c26d8d48dbbc6da7e2302012180053134e5 (diff)
downloadXMonadContrib-5256f6f0aa92b0c2c9a1cd5a45ef25014510eaa1.tar.gz
XMonadContrib-5256f6f0aa92b0c2c9a1cd5a45ef25014510eaa1.tar.xz
XMonadContrib-5256f6f0aa92b0c2c9a1cd5a45ef25014510eaa1.zip
Search.hs: +hackage search, courtesy of byorgey
Ignore-this: 24db0ceed49f8bd37ce98ccf8f8ca2ab darcs-hash:20081031214937-f7719-06cff30d637e6065e6684557420feabe769b600d.gz
Diffstat (limited to 'XMonad/Actions/Search.hs')
-rw-r--r--XMonad/Actions/Search.hs8
1 files changed, 6 insertions, 2 deletions
diff --git a/XMonad/Actions/Search.hs b/XMonad/Actions/Search.hs
index 65a6ddb..534b8c8 100644
--- a/XMonad/Actions/Search.hs
+++ b/XMonad/Actions/Search.hs
@@ -27,6 +27,7 @@ module XMonad.Actions.Search ( -- * Usage
debpts,
dictionary,
google,
+ hackage,
hoogle,
images,
imdb,
@@ -90,7 +91,9 @@ import XMonad.Util.XSelection (getSelection)
* 'google' -- basic Google search.
-* 'hoogle' -- Hoogle, the Haskell libraries search engine.
+* 'hackage' -- Hackage, the Haskell package database.
+
+* 'hoogle' -- Hoogle, the Haskell libraries API search engine.
* 'images' -- Google images.
@@ -211,7 +214,7 @@ searchEngine :: Name -> Site -> SearchEngine
searchEngine name site = SearchEngine name site
-- The engines.
-amazon, codesearch, deb, debbts, debpts, dictionary, google, hoogle, images,
+amazon, codesearch, deb, debbts, debpts, dictionary, google, hackage, hoogle, images,
imdb, isohunt, maps, mathworld, scholar, thesaurus, wayback, wikipedia,
youtube :: SearchEngine
amazon = searchEngine "amazon" "http://www.amazon.com/exec/obidos/external-search?index=all&keyword="
@@ -221,6 +224,7 @@ debbts = searchEngine "debbts" "http://bugs.debian.org/"
debpts = searchEngine "debpts" "http://packages.qa.debian.org/"
dictionary = searchEngine "dictionary" "http://dictionary.reference.com/browse/"
google = searchEngine "google" "http://www.google.com/search?num=100&q="
+hackage = searchEngine "hackage" "http://hackage.haskell.org/cgi-bin/hackage-scripts/package/"
hoogle = searchEngine "hoogle" "http://www.haskell.org/hoogle/?q="
images = searchEngine "images" "http://images.google.fr/images?q="
imdb = searchEngine "imdb" "http://www.imdb.com/Find?select=all&for="